==> duckdb_0.2.6.tar.gz: duckdb/src/duckdb/amalgamation-3.cpp <==
#include "src/execution/physical_plan/plan_simple.cpp"

#include "src/execution/physical_plan/plan_top_n.cpp"

#include "src/execution/physical_plan/plan_unnest.cpp"

#include "src/execution/physical_plan/plan_update.cpp"

#include "src/execution/physical_plan/plan_window.cpp"

#include "src/execution/physical_plan_generator.cpp"

#include "src/execution/reservoir_sample.cpp"

#include "src/execution/window_segment_tree.cpp"

#include "src/function/aggregate/algebraic/avg.cpp"

#include "src/function/aggregate/algebraic/corr.cpp"

#include "src/function/aggregate/algebraic/covar.cpp"

#include "src/function/aggregate/algebraic/stddev.cpp"

#include "src/function/aggregate/algebraic_functions.cpp"

#include "src/function/aggregate/distributive/approx_count.cpp"

#include "src/function/aggregate/distributive/arg_min_max.cpp"

#include "src/function/aggregate/distributive/bitagg.cpp"

#include "src/function/aggregate/distributive/bool.cpp"

#include "src/function/aggregate/distributive/count.cpp"

#include "src/function/aggregate/distributive/entropy.cpp"

#include "src/function/aggregate/distributive/first.cpp"

#include "src/function/aggregate/distributive/kurtosis.cpp"

#include "src/function/aggregate/distributive/minmax.cpp"

#include "src/function/aggregate/distributive/product.cpp"

#include "src/function/aggregate/distributive/skew.cpp"

#include "src/function/aggregate/distributive/string_agg.cpp"

#include "src/function/aggregate/distributive/sum.cpp"

#include "src/function/aggregate/distributive_functions.cpp"

#include "src/function/aggregate/holistic/approximate_quantile.cpp"

#include "src/function/aggregate/holistic/mode.cpp"

#include "src/function/aggregate/holistic/quantile.cpp"

#include "src/function/aggregate/holistic/reservoir_quantile.cpp"

#include "src/function/aggregate/holistic_functions.cpp"

#include "src/function/aggregate/nested/histogram.cpp"

#include "src/function/aggregate/nested/list.cpp"

#include "src/function/aggregate/nested_functions.cpp"

#include "src/function/aggregate/regression/regr_avg.cpp"

#include "src/function/aggregate/regression/regr_count.cpp"

#include "src/function/aggregate/regression/regr_intercept.cpp"

#include "src/function/aggregate/regression/regr_r2.cpp"

#include "src/function/aggregate/regression/regr_slope.cpp"

#include "src/function/aggregate/regression/regr_sxx_syy.cpp"

#include "src/function/aggregate/regression/regr_sxy.cpp"

#include "src/function/aggregate/regression_functions.cpp"

#include "src/function/cast_rules.cpp"

#include "src/function/function.cpp"

#include "src/function/macro_function.cpp"

#include "src/function/pragma/pragma_functions.cpp"

#include "src/function/pragma/pragma_queries.cpp"

#include "src/function/pragma_function.cpp"

#include "src/function/scalar/blob/base64.cpp"

#include "src/function/scalar/blob/encode.cpp"

#include "src/function/scalar/date/age.cpp"

#include "src/function/scalar/date/current.cpp"

#include "src/function/scalar/date/date_part.cpp"

#include "src/function/scalar/date/date_trunc.cpp"

#include "src/function/scalar/date/epoch.cpp"

#include "src/function/scalar/date/strftime.cpp"

#include "src/function/scalar/date/to_interval.cpp"

#include "src/function/scalar/date_functions.cpp"

#include "src/function/scalar/generic/alias.cpp"

#include "src/function/scalar/generic/constant_or_null.cpp"

#include "src/function/scalar/generic/current_setting.cpp"

#include "src/function/scalar/generic/least.cpp"

#include "src/function/scalar/generic/stats.cpp"

#include "src/function/scalar/generic/typeof.cpp"

#include "src/function/scalar/generic_functions.cpp"

#include "src/function/scalar/math/numeric.cpp"

#include "src/function/scalar/math/random.cpp"

#include "src/function/scalar/math/setseed.cpp"

#include "src/function/scalar/math_functions.cpp"

#include "src/function/scalar/nested/array_slice.cpp"

#include "src/function/scalar/nested/list_extract.cpp"

#include "src/function/scalar/nested/list_value.cpp"

#include "src/function/scalar/nested/struct_extract.cpp"

#include "src/function/scalar/nested/struct_pack.cpp"

#include "src/function/scalar/nested_functions.cpp"

#include "src/function/scalar/operators.cpp"

#include "src/function/scalar/operators/add.cpp"

#include "src/function/scalar/operators/arithmetic.cpp"

#include "src/function/scalar/operators/bitwise.cpp"

#include "src/function/scalar/operators/multiply.cpp"

#include "src/function/scalar/operators/subtract.cpp"

#include "src/function/scalar/pragma_functions.cpp"

#include "src/function/scalar/sequence/currval.cpp"

#include "src/function/scalar/sequence/nextval.cpp"

#include "src/function/scalar/sequence_functions.cpp"

#include "src/function/scalar/string/ascii.cpp"

#include "src/function/scalar/string/caseconvert.cpp"

#include "src/function/scalar/string/chr.cpp"

#include "src/function/scalar/string/concat.cpp"

#include "src/function/scalar/string/contains.cpp"

#include "src/function/scalar/string/instr.cpp"

#include "src/function/scalar/string/jaccard.cpp"

#include "src/function/scalar/string/left_right.cpp"

#include "src/function/scalar/string/length.cpp"

#include "src/function/scalar/string/levenshtein.cpp"

#include "src/function/scalar/string/like.cpp"

#include "src/function/scalar/string/md5.cpp"

#include "src/function/scalar/string/mismatches.cpp"

#include "src/function/scalar/string/nfc_normalize.cpp"

==> duckdb_0.2.7.tar.gz: duckdb/src/duckdb/amalgamation-3.cpp <==
#include "src/execution/physical_plan/plan_unnest.cpp"

#include "src/execution/physical_plan/plan_update.cpp"

#include "src/execution/physical_plan/plan_window.cpp"

#include "src/execution/physical_plan_generator.cpp"

#include "src/execution/reservoir_sample.cpp"

#include "src/execution/window_segment_tree.cpp"

#include "src/function/aggregate/algebraic/avg.cpp"

#include "src/function/aggregate/algebraic/corr.cpp"

#include "src/function/aggregate/algebraic/covar.cpp"

#include "src/function/aggregate/algebraic/stddev.cpp"

#include "src/function/aggregate/algebraic_functions.cpp"

#include "src/function/aggregate/distributive/approx_count.cpp"

#include "src/function/aggregate/distributive/arg_min_max.cpp"

#include "src/function/aggregate/distributive/bitagg.cpp"

#include "src/function/aggregate/distributive/bool.cpp"

#include "src/function/aggregate/distributive/count.cpp"

#include "src/function/aggregate/distributive/entropy.cpp"

#include "src/function/aggregate/distributive/first.cpp"

#include "src/function/aggregate/distributive/kurtosis.cpp"

#include "src/function/aggregate/distributive/minmax.cpp"

#include "src/function/aggregate/distributive/product.cpp"

#include "src/function/aggregate/distributive/skew.cpp"

#include "src/function/aggregate/distributive/string_agg.cpp"

#include "src/function/aggregate/distributive/sum.cpp"

#include "src/function/aggregate/distributive_functions.cpp"

#include "src/function/aggregate/holistic/approximate_quantile.cpp"

#include "src/function/aggregate/holistic/mode.cpp"

#include "src/function/aggregate/holistic/quantile.cpp"

#include "src/function/aggregate/holistic/reservoir_quantile.cpp"

#include "src/function/aggregate/holistic_functions.cpp"

#include "src/function/aggregate/nested/histogram.cpp"

#include "src/function/aggregate/nested/list.cpp"

#include "src/function/aggregate/nested_functions.cpp"

#include "src/function/aggregate/regression/regr_avg.cpp"

#include "src/function/aggregate/regression/regr_count.cpp"

#include "src/function/aggregate/regression/regr_intercept.cpp"

#include "src/function/aggregate/regression/regr_r2.cpp"

#include "src/function/aggregate/regression/regr_slope.cpp"

#include "src/function/aggregate/regression/regr_sxx_syy.cpp"

#include "src/function/aggregate/regression/regr_sxy.cpp"

#include "src/function/aggregate/regression_functions.cpp"

#include "src/function/cast_rules.cpp"

#include "src/function/function.cpp"

#include "src/function/macro_function.cpp"

#include "src/function/pragma/pragma_functions.cpp"

#include "src/function/pragma/pragma_queries.cpp"

#include "src/function/pragma_function.cpp"

#include "src/function/scalar/blob/base64.cpp"

#include "src/function/scalar/blob/encode.cpp"

#include "src/function/scalar/date/age.cpp"

#include "src/function/scalar/date/current.cpp"

#include "src/function/scalar/date/date_part.cpp"

#include "src/function/scalar/date/date_trunc.cpp"

#include "src/function/scalar/date/epoch.cpp"

#include "src/function/scalar/date/strftime.cpp"

#include "src/function/scalar/date/to_interval.cpp"

#include "src/function/scalar/date_functions.cpp"

#include "src/function/scalar/generic/alias.cpp"

#include "src/function/scalar/generic/constant_or_null.cpp"

#include "src/function/scalar/generic/current_setting.cpp"

#include "src/function/scalar/generic/least.cpp"

#include "src/function/scalar/generic/stats.cpp"

#include "src/function/scalar/generic/typeof.cpp"

#include "src/function/scalar/generic_functions.cpp"

#include "src/function/scalar/math/numeric.cpp"

#include "src/function/scalar/math/random.cpp"

#include "src/function/scalar/math/setseed.cpp"

#include "src/function/scalar/math_functions.cpp"

#include "src/function/scalar/nested/array_slice.cpp"

#include "src/function/scalar/nested/list_extract.cpp"

#include "src/function/scalar/nested/list_value.cpp"

#include "src/function/scalar/nested/map/cardinality.cpp"

#include "src/function/scalar/nested/map/map.cpp"

#include "src/function/scalar/nested/map_extract.cpp"

#include "src/function/scalar/nested/struct_extract.cpp"

#include "src/function/scalar/nested/struct_pack.cpp"

#include "src/function/scalar/nested_functions.cpp"

#include "src/function/scalar/operators.cpp"

#include "src/function/scalar/operators/add.cpp"

#include "src/function/scalar/operators/arithmetic.cpp"

#include "src/function/scalar/operators/bitwise.cpp"

#include "src/function/scalar/operators/multiply.cpp"

#include "src/function/scalar/operators/subtract.cpp"

#include "src/function/scalar/pragma_functions.cpp"

#include "src/function/scalar/sequence/currval.cpp"

#include "src/function/scalar/sequence/nextval.cpp"

#include "src/function/scalar/sequence_functions.cpp"

#include "src/function/scalar/string/ascii.cpp"

#include "src/function/scalar/string/caseconvert.cpp"

#include "src/function/scalar/string/chr.cpp"

#include "src/function/scalar/string/concat.cpp"

#include "src/function/scalar/string/contains.cpp"

#include "src/function/scalar/string/instr.cpp"

#include "src/function/scalar/string/jaccard.cpp"

#include "src/function/scalar/string/left_right.cpp"

#include "src/function/scalar/string/length.cpp"

#include "src/function/scalar/string/levenshtein.cpp"

#include "src/function/scalar/string/like.cpp"

#include "src/function/scalar/string/md5.cpp"

#include "src/function/scalar/string/mismatches.cpp"

#include "src/function/scalar/string/nfc_normalize.cpp"

#include "src/function/scalar/string/pad.cpp"

#include "src/function/scalar/string/prefix.cpp"
